@@ -1,3 +1,4 @@
+import asyncio
 import logging
 import random
 import time
@@ -143,7 +144,7 @@ class QCticJob(BaseJob):
         self.api.cancel_job_sync(self.job_id())
 
     @_fetch_job_sync
-    def result(self):
+    def result(self, poll=False, base_sleep=2, max_sleep=256, sleep_growth=2):
         """Return the results of the job.
 
         Args:
@@ -156,7 +157,17 @@ class QCticJob(BaseJob):
             JobError: If there was an error running the experiment on the remote simulator.
         """
 
-        return self._result()
+        sleep = base_sleep
+
+        while True:
+            res = self._result()
+
+            if res or not poll:
+                return res
+
+            time.sleep(sleep)
+            sleep = min(sleep * sleep_growth, max_sleep)
+            self._fetch_remote_job()
 
     @_fetch_job_async
     async def status_async(self):
@@ -169,5 +180,15 @@ class QCticJob(BaseJob):
         await self.api.cancel_job(self.job_id())
 
     @_fetch_job_async
-    async def result_async(self):
-        return self._result()
+    async def result_async(self, poll=False, base_sleep=2, max_sleep=256, sleep_growth=2):
+        sleep = base_sleep
+
+        while True:
+            res = self._result()
+
+            if res or not poll:
+                return res
+
+            await asyncio.sleep(sleep)
+            sleep = min(sleep * sleep_growth, max_sleep)
+            await self._fetch_remote_job_async()
