@@ -3,7 +3,7 @@ import datetime
 from marshmallow import (Schema, ValidationError, fields, post_load, pre_dump,
                          pre_load, validate, validates_schema)
 from qiskit.providers import JobStatus
-from qiskit.qobj import Qobj
+from qiskit.qobj import QasmQobj as Qobj
 from qiskit.result import Result
 
 
